chrono
######

to the king
===========

.. image:: informed.jpg

from the king
=============

.. image:: opdehoogte.jpg

.. include:: otpcr11719.rst

.. include:: otp1.rst

.. include:: reconsider.rst

.. include:: otp2.rst

todo
====

“Under the Rome Statute, the Court may only exercise jurisdiction over genocide,
crimes against humanity and war crimes, as defined in the Rome Statute (Articles
6 to 8), when commited on or after 1 July 2002 (Article 11). In addition, the
Court may only exercise jurisdiction over such crimes committed on the territory
of a State that has accepted the jurisdiction of the Court or by a national of
such State( Article 12) or where the Security Council refers the situation to the
Court (Article 13).”

One decision from a judge that it’s after 2002 and he has jurisiction over the
king his genocide, he can give an arrest warrant for the king, find the king
guilty of genocide, place him into his cell and declare the END over genocide.

END over GENOCIDE means every country an appointed genocide judge to take
down the powers that use laws to administer poison. These governments commit
genocide with these laws and will be prosecuted as such, thus eradicating
genocide from this planet.

contact
=======

| Bart Thate (bthate@dds.nl)
| botfather on #dunkbots at irc.freenode.net
